[PATCH 1/1] riscv: Add missing disassembler option `max`

Marek Pikuła m.pikula@partner.samsung.com
Tue Mar 25 13:46:16 GMT 2025


The flag already exists but it's not been exposed to user.

Signed-off-by: Marek Pikuła <m.pikula@partner.samsung.com>
---
 opcodes/riscv-dis.c | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/opcodes/riscv-dis.c b/opcodes/riscv-dis.c
index c341a0fe317..a8a89311ebf 100644
--- a/opcodes/riscv-dis.c
+++ b/opcodes/riscv-dis.c
@@ -66,7 +66,7 @@ struct riscv_private_data
   const char (*riscv_fpr_names)[NRC];
   /* If set, disassemble as most general instruction.  */
   bool no_aliases;
   /* If set, disassemble without checking architectire string, just like what
      we did at the beginning.  */
   bool all_ext;
 };
@@ -1577,6 +1577,9 @@ static struct
   riscv_option_arg_t arg;
 } riscv_options[] =
 {
+  { "max",
+    N_("Disassemble without checking architecture string."),
+    RISCV_OPTION_ARG_NONE },
   { "numeric",
     N_("Print numeric register names, rather than ABI names."),
     RISCV_OPTION_ARG_NONE },
@@ -66,7 +66,7 @@ struct riscv_private_data
   /* If set, disassemble as most general instruction.  */
   bool no_aliases;
-  /* If set, disassemble without checking architectire string, just like what
+  /* If set, disassemble without checking architecture string, just like what
      we did at the beginning.  */
   bool all_ext;
-- 
2.49.0



More information about the Binutils mailing list